# Generated by Django 3.2.6 on 2021-08-16 19:19

from django.db import migrations, models
import django.db.models.deletion
import djangocms_mdeditor.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '__first__'),
    ]

    operations = [
        migrations.CreateModel(
            name='MarkdownText',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='mdeditor_markdowntext', serialize=False, to='cms.cmsplugin')),
                ('body', djangocms_mdeditor.models.MarkdownField(verbose_name='body')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



# coding: utf-8
from django.contrib import admin
from .widgets import AdminMarkdownWidget
from .models import MarkdownField


class MarkdownModelAdmin(admin.ModelAdmin):
    formfield_overrides = {
        MarkdownField: {'widget': AdminMarkdownWidget}
    }



# coding: utf-8
from django.db import models
from django.utils.translation import gettext_lazy as _
from django.utils.html import strip_tags
from django.utils.text import Truncator
from cms.models import CMSPlugin
from martor.models import MartorField
from martor.utils import markdownify
from .fields import MarkdownFormField


class MarkdownField(MartorField):
    """
    Extend martor.models.MartorField to provide CSS-fix media-field.
    """
    def formfield(self, **kwargs):
        defaults = {'form_class': MarkdownFormField}
        defaults.update(kwargs)
        return super(MarkdownField, self).formfield(**defaults)


class MarkdownText(CMSPlugin):
    """
    Markdown Text Plugin Class.
    """
    body = MarkdownField(_('body'),)

    def __str__(self):
        return Truncator(strip_tags(markdownify(self.body)).replace(
            '&shy;', '')).words(3, truncate="...")



# coding: utf-8
from django.contrib.admin import widgets
from martor.widgets import MartorWidget


class MarkdownWidget(MartorWidget):
    """
    Extend of martor.widgets.MartorWidget() to incorporate extra css-files.
    """
    class Media:
        css = {'all': ('css/ace-djangocms-fix.min.css',)}


class AdminMarkdownWidget(MarkdownWidget, widgets.AdminTextareaWidget):
    pass



# coding: utf-8
from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from django.utils.translation import gettext as _
from .models import MarkdownText


@plugin_pool.register_plugin
class MarkdownPluginPublisher(CMSPluginBase):
    model = MarkdownText
    module = _("Texts")
    name = _("Markdown Text")
    render_template = "render_text_plugin.html"

    def render(self, context, instance, placeholder):
        context.update({'instance': instance})
        return context



# coding: utf-8
from setuptools import setup, find_packages
import pathlib
from djangocms_mdeditor import (__VERSION__, __AUTHOR__, __AUTHOR_EMAIL__)


here = pathlib.Path(__file__).parent.resolve()

setup(
    name='djangocms-mdeditor',
    version=__VERSION__,
    description='Text Plugin for django CMS using Martor for Markdown-enabled text-editing.',
    long_description=(here / 'README.md').read_text(encoding='utf-8'),
    long_description_content_type='text/markdown',
    keywords=['python', 'markdown', 'django', 'addon', 'django-cms'],
    url='https://github.com/danniranderis/djangocms-mdeditor',
    download_url='https://github.com/danniranderis/djangocms-mdeditor'
                 '/tarball/v%s' % __VERSION__,
    license='MIT',
    author=__AUTHOR__,
    author_email=__AUTHOR_EMAIL__,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        # 'Programming Language :: Python :: 3.7',
        # 'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3 :: Only',
        'Framework :: Django',
        'Framework :: Django :: 3.2',
        'Framework :: Django CMS',
        # 'Framework :: Django CMS 3.9',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries',
    ],
    python_requires='>=3.9',
    install_requires=[
        'django-cms>=3.9',
        'martor>=1.6.4',
    ],
    packages=find_packages(),
    include_package_data=True,
    # package_data={
    #     'ff': ['f']
    # },
)



# coding: utf-8
from martor.fields import MartorFormField
from .widgets import MarkdownWidget


class MarkdownFormField(MartorFormField):
    """
    Extend martor.fields.MartorFormField to provide CSS-fix media-field.
    """
    def __init__(self, *args, **kwargs):
        super(MarkdownFormField, self).__init__(*args, **kwargs)
        if not issubclass(self.widget.__class__, MarkdownWidget):
            self.widget = MarkdownWidget()
